@@ -1,5 +1,6 @@
 import json
 import re
+import os
 import sys
 import argparse
 import time
@@ -278,6 +279,8 @@ def experiment() -> None:
 
     sys.path.append(args.package_name)
 
+    sys.path.append(os.getcwd())
+
     maker = DynamicConfigMaker()
     msg = "Your config is {}. ".format(args.config)
     msg += "For now we assume config is json"
